#[repr(u8)]pub enum ExtendedCommand {
ExtendedBarcodeReply = 1,
ExtendedNoteSpecification = 2,
SetExtendedNoteInhibits = 3,
SetEscrowTimeout = 4,
QueryValueTable = 6,
NoteRetrieved = 11,
AdvancedBookmark = 13,
ClearAuditDataRequest = 29,
Reserved = 255,
}Expand description
Extended Commands (Type 7): The extended commands utilize message type 7 to provide functionality outside of the standard omnibus commands. The use of message type 7 is complicated by the fact that it can be used by either the host or device at anytime.
Developers: add additional types from the specification as needed
Variants
ExtendedBarcodeReply = 1
ExtendedNoteSpecification = 2
SetExtendedNoteInhibits = 3
SetEscrowTimeout = 4
QueryValueTable = 6
NoteRetrieved = 11
AdvancedBookmark = 13
ClearAuditDataRequest = 29
Reserved = 255