pub struct ExtendedNoteInhibitsReplyAlt { /* private fields */ }Expand description
Represents an alternate reply for a SetExtendedNoteInhibits command.
In some firmware, an alternate reply is given. This reply also contains no extended data.
The Extended Note Inhibits Alternate Reply is formatted as follows:
| Name | STX | LEN | CTRL | Subtype | Data 0 | Data 1 | Data 2 | Data 3 | Data 4 | Data 5 | ETX | CHK |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| Byte | 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 |
| Value | 0x02 | 0x0C | 0x7n | 0x03 | nn | nn | nn | nn | nn | nn | 0x03 | zz |
WARNING In order to avoid possible confusion processing the extended note data, this command should only be sent when the device is in the idle state.
Implementations
Sourceimpl ExtendedNoteInhibitsReplyAlt
impl ExtendedNoteInhibitsReplyAlt
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new ExtendedNoteInhibitsReplyAlt message.