NoteRetrievedEvent

Struct NoteRetrievedEvent 

pub struct NoteRetrievedEvent { /* private fields */ }
Note Retrieved - Event (Subtype 0x0B)

If the functionality has been enabled, the device will send out a message each time the note is removed after a return/reject.

The Note Retrieved Event is formatted as follows:

NameSTXLENCTRLSubtypeData 0Data 1Data 2Data 3Data 4Data 5EventETXCHK
Byte0123456789101112
Value0x020x0D0x7n0x0Bnnnnnnnnnnnn0x7F0x03zz

The 0x7F for the `Event byte signifies that the note has been removed by the user.

Implementations

Source

impl NoteRetrievedEvent

pub fn new() -> Self

pub fn retrieved_event(&self) -> u8