pub struct VariantPartNumber { /* private fields */ }Expand description
The part number is composed of a project number (5-6 digits) and version number (3 digits) with an optional Check sum digit in the middle. Please see the following table for expected values.
Implementations
Sourceimpl VariantPartNumber
impl VariantPartNumber
Sourcepub const LEN: usize = 9
pub const LEN: usize = 9
The length (in bytes) of the VariantPartNumber.
Sourcepub const fn new(project_number: ProjectNumber, version: PartVersion) -> Self
pub const fn new(project_number: ProjectNumber, version: PartVersion) -> Self
Creates a new VariantPartNumber.
pub const fn default() -> Self