#[repr(u8)]pub enum Paused {
Unset = 0,
Set = 1,
}Expand description
The customer is attempting to feed another note while the previous note is still being processed. The customer must remove the note to permit processing to continue.
Variants