ExceptionStatus

Struct ExceptionStatus 

pub struct ExceptionStatus(pub u8);
ExceptionStatus contains additional information on exceptional statuses as well as the reporting of the note value. (Non-extended mode only.)

ExceptionStatus is a bitfield, representing the following:

Tuple Fields

0: u8

Implementations

Source

impl ExceptionStatus

pub fn power_up(&self) -> bool

Unset (0): The device is operating normally (Power up process is complete) Set (1): The device has been powered up. It is performing its initialization routine, and not yet ready to accept documents.

pub fn invalid_command(&self) -> bool

The device received an invalid command.

pub fn failure(&self) -> bool

The device has encountered a problem and is out of service. Intervention is required.

pub fn note_value(&self) -> u8

The non-extended note value field. This field is valid when the device is in non- extended mode and either the escrow or stacked bits are set. (See Omnibus Reply – Data Byte 0 for details of those events)

000 - Unknown/No credit 001 - Denom1 010 - Denom2 011 - Denom3 100 - Denom4 101 - Denom5 110 - Denom6 111 - Denom7

pub fn transport_open(&self) -> bool

Unset (0) - Note path access is closed Set (1) - Note path access is opened (vault, door, or both).

WARNING: This bit will also be reported one time upon power up if the note path was opened while the unit was powered down.

pub fn set_power_up(&mut self, value: bool)

Unset (0): The device is operating normally (Power up process is complete) Set (1): The device has been powered up. It is performing its initialization routine, and not yet ready to accept documents.

pub fn set_invalid_command(&mut self, value: bool)

The device received an invalid command.

pub fn set_failure(&mut self, value: bool)

The device has encountered a problem and is out of service. Intervention is required.

pub fn set_note_value(&mut self, value: u8)

The non-extended note value field. This field is valid when the device is in non- extended mode and either the escrow or stacked bits are set. (See Omnibus Reply – Data Byte 0 for details of those events)

000 - Unknown/No credit 001 - Denom1 010 - Denom2 011 - Denom3 100 - Denom4 101 - Denom5 110 - Denom6 111 - Denom7

pub fn set_transport_open(&mut self, value: bool)

Unset (0) - Note path access is closed Set (1) - Note path access is opened (vault, door, or both).

WARNING: This bit will also be reported one time upon power up if the note path was opened while the unit was powered down.

Source

impl ExceptionStatus

pub const fn none() -> Self

Create an ExceptionStatus with no bits set.